@@ -20,6 +20,7 @@ def label_assignment_cost(labels1,labels2,label1,label2):
 
 def get_trans_dict(trans_from_labels,trans_to_labels,subsample_size):
     # First compress each labelling, retain compression dicts
+    subsample_size = min(len(trans_from_labels),subsample_size)
     trans_from_labels, tdf, _ = compress_labels(trans_from_labels)
     trans_to_labels, tdt, _ = compress_labels(trans_to_labels)
     reverse_tdf = {v:k for k,v in tdf.items()}
@@ -133,8 +134,7 @@ def f1(bin_classifs_pred,bin_classifs_gt):
     rec = tp/(tp+fn)
     return (2*prec*rec)/(prec+rec)
 
-def mean_f1(labels1,labels2):
-    subsample_size = min(len(labels1),30000)
+def mean_f1(labels1,labels2,subsample_size=30000):
     trans_labels = translate_labellings(labels1,labels2,subsample_size)
     lab_f1s = []
     for lab in unique_labels(trans_labels):
